==> af-android-sdk-4.8.3-sources.jar: com/appsflyer/AFLifecycleCallbacks.java <==
package com.appsflyer;

import android.content.Context;
import android.content.pm.PackageManager;

import java.lang.ref.WeakReference;

/**
 * @author by shacharaharon on 19/01/2017.
 */

class AFLifecycleCallbacks {

    static void doOnResume(Context context) {
        AFLogger.afInfoLog("onBecameForeground");
        AppsFlyerLib.getInstance().resetTimeEnteredForeground();
        AppsFlyerLib.getInstance().trackEventInternal(context, null, null);

        AFLogger.resetDeltaTime();
    }

    static void doOnPause(Context context) {
        AFLogger.afInfoLog("onBecameBackground");
        AppsFlyerLib.getInstance().resetTimeWentToBackground();
        AFLogger.afInfoLog("callStatsBackground background call");
        WeakReference<Context> weakContext = new WeakReference<>(context.getApplicationContext());
        AppsFlyerLib.getInstance().callStatsBackground(weakContext);
        RemoteDebuggingManager rdInstance = RemoteDebuggingManager.getInstance();
        if (rdInstance.isRemoteDebuggingEnabledFromServer()) {
            rdInstance.stopRemoteDebuggingMode();
            if (weakContext.get() != null) {
                String packageName = weakContext.get().getPackageName();
                PackageManager packageManager = weakContext.get().getPackageManager();
                rdInstance.sendRemoteDebuggingData(packageName,packageManager);
            }
            rdInstance.releaseRemoteDebugging();
        } else {
            AFLogger.afDebugLog("RD status is OFF");
        }

        AFExecutor.getInstance().shutdownExecutors();
    }

}

==> af-android-sdk-4.8.6-sources.jar: com/appsflyer/AFLifecycleCallbacks.java <==
package com.appsflyer;

import android.content.Context;
import android.content.pm.PackageManager;

import java.lang.ref.WeakReference;

/**
 * @author by shacharaharon on 19/01/2017.
 */

class AFLifecycleCallbacks {

    static void doOnResume(Context context) {
        AFLogger.afInfoLog("onBecameForeground");
        AppsFlyerLib.getInstance().resetTimeEnteredForeground();
        AppsFlyerLib.getInstance().trackEventInternal(context, null, null);

        AFLogger.resetDeltaTime();
    }

    static void doOnPause(Context context) {
        AFLogger.afInfoLog("onBecameBackground");
        AppsFlyerLib.getInstance().resetTimeWentToBackground();
        AFLogger.afInfoLog("callStatsBackground background call");
        WeakReference<Context> weakContext = new WeakReference<>(context.getApplicationContext());
        AppsFlyerLib.getInstance().callStatsBackground(weakContext);
        ProxyManager rdInstance = ProxyManager.getInstance();
        if (rdInstance.isProxyEnabledFromServer()) {
            rdInstance.stopProxyMode();
            if (weakContext.get() != null) {
                String packageName = weakContext.get().getPackageName();
                PackageManager packageManager = weakContext.get().getPackageManager();
                rdInstance.sendProxyData(packageName,packageManager);
            }
            rdInstance.releaseProxy();
        } else {
            AFLogger.afDebugLog("RD status is OFF");
        }

        AFExecutor.getInstance().shutdownExecutors();
    }

}
